# Standard textclass definition file. Taken from initial LyX source code
# Author : Matthias Ettrich <ettrich@informatik.uni-tuebingen.de>
# Transposed by Pascal André <andre@via.ecp.fr>
# Heavily modifed and enhanced by several developers.

# This include file contains all numbered sectionning-related
# commands that are useful for article-like document classes, but not
# for letters.

Format 60

Style "Раздел"
	Category              "Раздел"
	Margin                Dynamic
	LabelType             Static
	LabelCounter          section
	LabelString           \thesection.
	TocLevel              1
	LatexType             Command
	LatexName             ESPDsection
	NeedProtect           1
	NextNoIndent          0
	ToggleIndent          Never
	LabelSep              xxx
	ParSkip               0.4
	TopSep                1.3
	LeftMargin            "MMMMM"
	BottomSep             0.7
	ParSep                0.7
	Align                 Block
	Argument 1
		LabelString   "Short Title|S"
		Tooltip       "The section as it appears in the table of contents/running headers"
		InsertCotext  1
	EndArgument
	Font
		Series            Bold
		Size              Larger
	EndFont
	HTMLTag               h2
	Preamble
		\newcommand{\ESPDsection}[1]{
		  \section{#1}
		  \setcounter{point}{\value{section}}
		  \setcounter{subpoint}{0}
		}
	EndPreamble
End


Style "Подраздел"
	CopyStyle             "Раздел"
	LabelCounter          subsection
	LabelString           \thesubsection.
	TocLevel              2
	LatexName             ESPDsubsection
	LeftMargin            "MMMMM"
	NextNoIndent          0
	TopSep                0.9
	BottomSep             0.5
	ParSep                0.5
	Font
		Series            Bold
		Size              Large
	EndFont
	HTMLTag               h3
	Preamble
		\newcommand{\ESPDsubsection}[1]{
		  \subsection{#1}
		  \setcounter{point}{\value{subsection}}
		  \setcounter{subpoint}{0}
		}
	EndPreamble
End


Style "Подподраздел"
	CopyStyle             "Подраздел"
	LabelCounter          subsubsection
	LabelString           \thesubsubsection.
	TocLevel              3
	LatexName             ESPDsubsubsection
	LeftMargin            "MMMMM"
	NextNoIndent          0
	TopSep                0.7
	BottomSep             0.4
	Font
		Series            Bold
		Size              Normal
	EndFont
	HTMLTag               h4
	Preamble
		\newcommand{\ESPDsubsubsection}[1]{
		  \subsubsection{#1}
		  \setcounter{point}{\value{subsubsection}}
		  \setcounter{subpoint}{0}
		}
	EndPreamble
End

Style "Пункт 2 уровень"
	Category              "Пункты после разделов"
	Margin                First_Dynamic
	LabelType             Static
	LabelCounter          pointII
	LabelString           \thepointII.
	KeepEmpty             1
	LatexType             Command
	LatexName             pointII
#	NeedProtect           0
#	NextNoIndent          1
	LabelSep              xxx
	ParSkip               0.4
	Align                 Block
	AlignPossible         Block, Left, Right, Center
End


Style "Пункт 3 уровень"
	Category              "Пункты после разделов"
	Margin                First_Dynamic
	LabelType             Static
	LabelCounter          pointIII
	LabelString           \thepointIII.
	KeepEmpty             1
	LatexType             Command
	LatexName             pointIII
	NeedProtect           0
	NextNoIndent          0
	LabelSep              xxx
	ParSkip               0.4
	TopSep                0.4
	BottomSep             0
End


Style "Пункт 4 уровень"
	Category              "Пункты после разделов"
	Margin                First_Dynamic
	LabelType             Static
	LabelCounter          pointIV
	LabelString           \thepointIV.
	KeepEmpty             1
	LatexType             Command
	LatexName             pointIV
	NeedProtect           0
	NextNoIndent          0
	LabelSep              xxx
	ParSkip               0.4
	TopSep                0.4
	BottomSep             0
End


Style "Подпункт 3 уровень"
	Category              "Подпункты после пунктов"
	Margin                First_Dynamic
	LabelType             Static
	LabelCounter          subpointIII
	LabelString           \thesubpointIII.
	KeepEmpty             1
	LatexType             Command
	LatexName             subpointIII
	NeedProtect           0
	NextNoIndent          0
	LabelSep              xxx
	ParSkip               0.4
	TopSep                0.4
	BottomSep             0
End


Style "Подпункт 4 уровень"
	Category              "Подпункты после пунктов"
	Margin                First_Dynamic
	LabelType             Static
	LabelCounter          subpointIV
	LabelString           \thesubpointIV.
	KeepEmpty             1
	LatexType             Command
	LatexName             subpointIV
	NeedProtect           0
	NextNoIndent          0
	LabelSep              xxx
	ParSkip               0.4
	TopSep                0.4
	BottomSep             0
End


Style "Обязательное"
	Category              "Приложение"
	Margin                Dynamic
	LabelType             Static
	LabelString           "Прил. Обязат. "
	LabelCounter          appendix
	TocLevel              1
	LatexType             Command
	LatexName             ESPDappendixReq
	NeedProtect           1
	NextNoIndent          1
	LabelSep              xxx
	ParSkip               0.4
	TopSep                1.3
	BottomSep             0.7
	ParSep                0.7
	Align                 Block
	AlignPossible         Block, Left
	Font
		Series            Bold
		Size              Larger
	EndFont
	Preamble
		\newcommand{\ESPDappendixReq}[1]{
		  \ESPDappendix{"Обязательное"}{#1}
		}
	EndPreamble
End

Style "Справочное"
	CopyStyle             "Обязательное"
	LabelString           "Прил. Справоч. "
	LatexName             ESPDappendixRef
	Preamble
		\newcommand{\ESPDappendixRef}[1]{
		  \ESPDappendix{"Справочное"}{#1}
		}
	EndPreamble
End

Style "Рекомендуемое"
	CopyStyle             "Обязательное"
	LabelString           "Прил. Рекоменд. "
	LatexName             ESPDappendixRec
	Preamble
		\newcommand{\ESPDappendixRec}[1]{
		  \ESPDappendix{"Рекомендуемое"}{#1}
		}
	EndPreamble
End

